[commit: ghc] master: Comments only [ci skip] (9ff0574)

git at git.haskell.org git at git.haskell.org
Thu Mar 9 09:40:36 UTC 2017


Repository : ssh://git@git.haskell.org/ghc

On branch  : master
Link       : http://ghc.haskell.org/trac/ghc/changeset/9ff05742de1ec1838c0fd358b194b29c8b3ed10b/ghc

>---------------------------------------------------------------

commit 9ff05742de1ec1838c0fd358b194b29c8b3ed10b
Author: Gabor Greif <ggreif at gmail.com>
Date:   Thu Mar 9 10:22:28 2017 +0100

    Comments only [ci skip]


>---------------------------------------------------------------

9ff05742de1ec1838c0fd358b194b29c8b3ed10b
 compiler/coreSyn/PprCore.hs                              | 2 +-
 compiler/iface/TcIface.hs                                | 2 +-
 compiler/simplCore/Simplify.hs                           | 4 ++--
 compiler/typecheck/FunDeps.hs                            | 2 +-
 compiler/typecheck/TcTypeable.hs                         | 2 +-
 libraries/template-haskell/Language/Haskell/TH/Syntax.hs | 2 +-
 6 files changed, 7 insertions(+), 7 deletions(-)

diff --git a/compiler/coreSyn/PprCore.hs b/compiler/coreSyn/PprCore.hs
index ddece8d..28d3552 100644
--- a/compiler/coreSyn/PprCore.hs
+++ b/compiler/coreSyn/PprCore.hs
@@ -338,7 +338,7 @@ Furthermore, a dead case-binder is completely ignored, while otherwise, dead
 binders are printed as "_".
 -}
 
--- THese instances are sadly orphans
+-- These instances are sadly orphans
 
 instance OutputableBndr Var where
   pprBndr = pprCoreBinder
diff --git a/compiler/iface/TcIface.hs b/compiler/iface/TcIface.hs
index 2d30f52..3a6a407 100644
--- a/compiler/iface/TcIface.hs
+++ b/compiler/iface/TcIface.hs
@@ -255,7 +255,7 @@ mergeIfaceDecl d1 d2
 --
 -- A module that defines T as representational in both arguments
 -- would successfully fill both signatures, so it would be better
--- if if we merged the roles of these types in some nontrivial
+-- if we merged the roles of these types in some nontrivial
 -- way.
 --
 -- However, we have to be very careful about how we go about
diff --git a/compiler/typecheck/FunDeps.hs b/compiler/typecheck/FunDeps.hs
index 058a971..981702f 100644
--- a/compiler/typecheck/FunDeps.hs
+++ b/compiler/typecheck/FunDeps.hs
@@ -52,7 +52,7 @@ Each functional dependency with one variable in the RHS is responsible
 for generating a single equality. For instance:
      class C a b | a -> b
 The constraints ([Wanted] C Int Bool) and [Wanted] C Int alpha
-will generate the folloing FunDepEqn
+will generate the following FunDepEqn
      FDEqn { fd_qtvs = []
            , fd_eqs  = [Pair Bool alpha]
            , fd_pred1 = C Int Bool
diff --git a/compiler/typecheck/TcTypeable.hs b/compiler/typecheck/TcTypeable.hs
index b67ae54..8dfad6d 100644
--- a/compiler/typecheck/TcTypeable.hs
+++ b/compiler/typecheck/TcTypeable.hs
@@ -125,7 +125,7 @@ There are many wrinkles:
   reduce the number of bindings we need to produce, we generate their KindReps
   once in GHC.Types. These are referred to as "built-in" KindReps below.
 
-* Even though KindReps aren't inlined this scheme still has more of an effect on
+* Even though KindReps aren't inlined, this scheme still has more of an effect on
   compilation time than I'd like. This is especially true in the case of
   families of type constructors (e.g. tuples and unboxed sums). The problem is
   particularly bad in the case of sums, since each arity-N tycon brings with it
diff --git a/libraries/template-haskell/Language/Haskell/TH/Syntax.hs b/libraries/template-haskell/Language/Haskell/TH/Syntax.hs
index 466834a..8be48aa 100644
--- a/libraries/template-haskell/Language/Haskell/TH/Syntax.hs
+++ b/libraries/template-haskell/Language/Haskell/TH/Syntax.hs
@@ -784,7 +784,7 @@ package `text` we find
   packConstr :: Constr
   packConstr = mkConstr textDataType "pack" [] Prefix
 
-Here `packConstr` isn't a real data constructor, it's an ordiary
+Here `packConstr` isn't a real data constructor, it's an ordinary
 function.  Two complications
 
 * In such a case, we must take care to build the Name using



More information about the ghc-commits mailing list
diff --git a/compiler/simplCore/Simplify.hs b/compiler/simplCore/Simplify.hs
index 969fb3e..b63e745 100644
--- a/compiler/simplCore/Simplify.hs
+++ b/compiler/simplCore/Simplify.hs
@@ -1814,7 +1814,7 @@ tryRules env rules fn args call_cont
                               -- many args the rule consumed
 
                       occ_anald_rhs = occurAnalyseExpr rule_rhs
                           -- See Note [Occurence-analyse after rule firing]
                 ; dump dflags rule rule_rhs
                 ; return (Just (occ_anald_rhs, cont')) }}}
   where
@@ -1847,7 +1847,7 @@ tryRules env rules fn args call_cont
       = liftIO . dumpSDoc dflags alwaysQualify flag "" $
                    sep [text hdr, nest 4 details]
 
-{- Note [Occurence-analyse after rule firing]
+{- Note [Occurrence-analyse after rule firing]
 ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 After firing a rule, we occurrence-analyse the instantiated RHS before
 simplifying it.  Usually this doesn't make much difference, but it can
@@ -1814,7 +1814,7 @@ tryRules env rules fn args call_cont
 
                       occ_anald_rhs = occurAnalyseExpr rule_rhs
-                          -- See Note [Occurence-analyse after rule firing]
+                          -- See Note [Occurrence-analyse after rule firing]
                 ; dump dflags rule rule_rhs
                 ; return (Just (occ_anald_rhs, cont')) }}}